#
# spec file for package gammaray
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor qt6%{nil}
%if "%{flavor}" == "qt6"
%define qt6 1
%define pkg_suffix -qt6
%define qt_suffix 6
%else
%define qt5 1
%define qt_suffix 5
%endif
%define rname gammaray
%define short_version 3.0
%define soversion 3_0_0
Name:           gammaray%{?pkg_suffix}
Version:        3.0.0
Release:        3.2
Summary:        Introspection/Debugging Tool for Qt Applications
License:        GPL-2.0-or-later
URL:            https://www.kdab.com/gammaray
Source:         https://github.com/KDAB/GammaRay/releases/download/v%{version}/%{rname}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM
Patch0:         0001-Fix-doc-tools-detection.patch
# PATCH-FIX-UPSTREAM
Patch1:         gammaray-gles.patch
Patch2:         0001-Fix-Qt-6.6-build.patch
Patch3:         0001-Repair-lack-of-classnames-in-Graphics-Scenes-or-Styl.patch
Patch4:         0001-QuickSceneGraphModel-don-t-nest-row-insertion-remova.patch
Patch5:         0001-Fix-gcc-13-warnings-about-references-to-temporaries.patch
Patch6:         0001-Fix-3-bugs-detected-by-QAbstractItemModelTester.patch
Patch7:         0001-Fix-two-issues-in-ObjectEnumModel-found-by-QAbstract.patch
Patch8:         0001-2-more-QAbstractItemModelTester-fixes.patch
Patch9:         0001-Unbreak-recursive-filtering-in-ObjectIdsFilterProxyM.patch
Patch10:        0001-Enable-building-with-Qt-6.7.patch
Patch11:        0001-Fix-build-on-6.7-for-after-QDeferredDeleteEvent-expo.patch
BuildRequires:  binutils-devel
BuildRequires:  cmake >= 3.16.0
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  graphviz-gnome
# include this so the icon folders don't need to be owned by the package
BuildRequires:  hicolor-icon-theme
BuildRequires:  libdw-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  cmake(Qt%{qt_suffix}3DAnimation)
BuildRequires:  cmake(Qt%{qt_suffix}3DExtras)
BuildRequires:  cmake(Qt%{qt_suffix}3DInput)
BuildRequires:  cmake(Qt%{qt_suffix}3DLogic)
BuildRequires:  cmake(Qt%{qt_suffix}3DQuick)
BuildRequires:  cmake(Qt%{qt_suffix}3DRender)
BuildRequires:  cmake(Qt%{qt_suffix}Bluetooth)
BuildRequires:  cmake(Qt%{qt_suffix}Concurrent)
BuildRequires:  cmake(Qt%{qt_suffix}Core)
BuildRequires:  cmake(Qt%{qt_suffix}Designer)
BuildRequires:  cmake(Qt%{qt_suffix}Gui)
BuildRequires:  cmake(Qt%{qt_suffix}Help)
BuildRequires:  cmake(Qt%{qt_suffix}LinguistTools)
BuildRequires:  cmake(Qt%{qt_suffix}Network)
BuildRequires:  cmake(Qt%{qt_suffix}OpenGL)
BuildRequires:  cmake(Qt%{qt_suffix}Positioning)
BuildRequires:  cmake(Qt%{qt_suffix}Qml)
BuildRequires:  cmake(Qt%{qt_suffix}Quick)
BuildRequires:  cmake(Qt%{qt_suffix}QuickWidgets)
BuildRequires:  cmake(Qt%{qt_suffix}Scxml)
BuildRequires:  cmake(Qt%{qt_suffix}Svg)
BuildRequires:  cmake(Qt%{qt_suffix}Test)
BuildRequires:  cmake(Qt%{qt_suffix}WaylandCompositor)
BuildRequires:  cmake(Qt%{qt_suffix}Widgets)
BuildRequires:  pkgconfig(wayland-server)
Requires:       %{name}-shared-plugins = %{version}
%if 0%{?qt5}
BuildRequires:  libQt5Core-private-headers-devel
BuildRequires:  libQt5Gui-private-headers-devel
BuildRequires:  libQt5Widgets-private-headers-devel
BuildRequires:  libqt5-qtdeclarative-private-headers-devel
BuildRequires:  libqt5-qtscxml-private-headers-devel
BuildRequires:  libqt5-qttools-doc
# No Qt6 support in current release
BuildRequires:  cmake(KDSME)
BuildRequires:  cmake(KF5CoreAddons)
BuildRequires:  cmake(KF5SyntaxHighlighting)
BuildRequires:  cmake(Qt5AttributionsScannerTools)
BuildRequires:  cmake(Qt5Location)
BuildRequires:  cmake(Qt5Script)
BuildRequires:  cmake(Qt5ScriptTools)
Recommends:     gammaray-qt6-shared-plugins = %{version}
%ifnarch ppc64 ppc64le s390 s390x
BuildRequires:  cmake(Qt5WebEngineWidgets)
%endif
%endif
%if 0%{?qt6}
BuildRequires:  qt6-core-private-devel
BuildRequires:  qt6-gui-private-devel
BuildRequires:  qt6-qml-private-devel
BuildRequires:  qt6-quick-private-devel
BuildRequires:  qt6-scxml-private-devel
BuildRequires:  qt6-widgets-private-devel
%if 0%{?suse_version} > 1500 || 0%{?sle_version} > 150500
BuildRequires:  cmake(Qt6Location)
%endif
BuildRequires:  cmake(Qt6ShaderTools)
BuildRequires:  cmake(Qt6ToolsTools)
Recommends:     gammaray-shared-plugins = %{version}
Conflicts:      gammaray
%ifnarch %{ix86} %{arm} ppc64 ppc64le s390 s390x
BuildRequires:  cmake(Qt6WebEngineWidgets)
%endif
%endif
# Pull in the correct set of shared libraries (Qt5/Qt6)
Requires:       libgammaray%{?pkg_suffix}-%{soversion} >= %{version}

%description
Gamma Ray is a comprehensive collection of high level introspection
and debugging utilities specifically tailored for the various
frameworks in Qt.

%package shared-plugins
Summary:        Shared plugins and libraries
Requires:       (gammaray = %{version} or gammaray-qt6 = %{version})

%description shared-plugins
This package ships libraries and plugins built with a different Qt version.
There are required in order to inspect executables built with different
Qt versions.

%package -n libgammaray%{?pkg_suffix}-%{soversion}
Summary:        Gammaray libraries
%if 0%{?qt6}
Conflicts:      libgammaray-%{soversion}
%endif

%description -n libgammaray%{?pkg_suffix}-%{soversion}
Gammaray libraries.

%package -n libgammaray-shared%{?pkg_suffix}-%{soversion}
Summary:        Shared Gammaray libraries used by either gammaray or gammaray-qt6

%description -n libgammaray-shared%{?pkg_suffix}-%{soversion}
This package provides libraries required by %{name}-shared-plugins

%package devel
Summary:        Introspection/Debugging Tool for Qt Applications
Requires:       libgammaray%{?pkg_suffix}-%{soversion}
Requires:       libgammaray-shared%{?pkg_suffix}-%{soversion}
%if 0%{?qt6}
Conflicts:      gammaray-devel
%endif

%description devel
Gamma Ray is a comprehensive collection of high level introspection
and debugging utilities specifically tailored for the various
frameworks in Qt. Development files.

%prep
%autosetup -p1 -n %{rname}-%{version}

%build
%define _lto_cflags %{nil}
%if 0%{?qt5}
%cmake \
  -DQT_VERSION_MAJOR=5 \
  -DECM_MKSPECS_INSTALL_DIR=%{_libdir}/qt5/mkspecs/modules \
  -DQCH_INSTALL_DIR=%{_datadir}/gammaray
%cmake_build
%endif

%if 0%{?qt6}
%cmake_qt6 \
  -DQT_VERSION_MAJOR=6 \
  -DECM_MKSPECS_INSTALL_DIR=%{_qt6_mkspecsdir}/modules \
  -DQCH_INSTALL_DIR=%{_datadir}/gammaray \
  -DQDOC_INDEX_DIR=%{_qt6_docdir}
%qt6_build
%endif

%install
%if 0%{?qt5}
%cmake_install
%endif

%if 0%{?qt6}
%qt6_install
%endif

# Already packaged with %%doc and %%license tags
rm -r %{buildroot}%{_datadir}/doc

%suse_update_desktop_file GammaRay Development Debugger

%fdupes %{buildroot}

%ldconfig_scriptlets -n libgammaray%{?pkg_suffix}-%{soversion}
%ldconfig_scriptlets -n libgammaray-shared%{?pkg_suffix}-%{soversion}

%files
%doc CHANGES README.md
%{_bindir}/gammaray
%{_datadir}/applications/GammaRay.desktop
# Scaled directories are not owned by hicolor
%dir %{_datadir}/icons/hicolor/*@*/
%dir %{_datadir}/icons/hicolor/*@*/apps/
%{_datadir}/icons/hicolor/*/apps/GammaRay.png
%dir %{_datadir}/zsh
%dir %{_datadir}/zsh/site-functions
%{_datadir}/zsh/site-functions/_gammaray
%dir %{_libdir}/gammaray
%{_libdir}/gammaray/libexec/
%{_mandir}/man1/gammaray.1%{?ext_man}
%{_datadir}/metainfo/com.kdab.GammaRay.metainfo.xml
%{_datadir}/gammaray/

%files -n libgammaray%{?pkg_suffix}-%{soversion}
%license LICENSES/*
%{_libdir}/libgammaray_client.so.*
%{_libdir}/libgammaray_kuserfeedback.so.*
%{_libdir}/libgammaray_launcher.so.*
%{_libdir}/libgammaray_launcher_ui.so.*

%files -n libgammaray-shared%{?pkg_suffix}-%{soversion}
%{_libdir}/libgammaray_*-qt*.so.*

# Shared libraries and plugins to load e.g. Qt 5 executables if gammaray was
# built with Qt 6
%files shared-plugins
%dir %{_libdir}/gammaray
%{_libdir}/gammaray/%{short_version}/

%files devel
%{_includedir}/gammaray/
%{_libdir}/cmake/GammaRay/
%{_libdir}/libgammaray_*-qt*.so
%{_libdir}/libgammaray_client.so
%{_libdir}/libgammaray_kuserfeedback.so
%{_libdir}/libgammaray_launcher.so
%{_libdir}/libgammaray_launcher_ui.so
%{_libdir}/qt*/mkspecs/modules/qt_GammaRay*.pri

%changelog
* Sat Apr  6 2024 Christophe Marin <christophe@krop.fr>
- Add upstream changes:
  * 0001-Fix-Qt-6.6-build.patch
  * 0001-Repair-lack-of-classnames-in-Graphics-Scenes-or-Styl.patch
  * 0001-QuickSceneGraphModel-don-t-nest-row-insertion-remova.patch
  * 0001-Fix-gcc-13-warnings-about-references-to-temporaries.patch
  * 0001-Fix-3-bugs-detected-by-QAbstractItemModelTester.patch
  * 0001-Fix-two-issues-in-ObjectEnumModel-found-by-QAbstract.patch
  * 0001-2-more-QAbstractItemModelTester-fixes.patch
  * 0001-Unbreak-recursive-filtering-in-ObjectIdsFilterProxyM.patch
  * 0001-Enable-building-with-Qt-6.7.patch
  * 0001-Fix-build-on-6.7-for-after-QDeferredDeleteEvent-expo.patch
* Sat Nov 25 2023 Fabian Vogt <fabian@ritter-vogt.de>
- Add dependency for the matching shared libraries
* Tue Sep  5 2023 Christophe Marin <christophe@krop.fr>
- Update to 3.0.0
  * Port to Qt6.
  * Network operations now optionally allow capturing HTTP
    response body.
  * Objects can now be favorited via context menu. A favorited
    object appears in a separate item view above the main itemview
  * Add support for modifying QMargins in properties
  * Allow zooming with mouse wheel in Signals view
  * Filtering for an object now automatically expands the tree
    and selects the object
  * Fix a crash when an object is re-parented
  * Improved performance of signals view
  * Improved performance when target application triggers massive
    object destructions/constructions
  * Remove the KDAB commercial license.
  * Remove the 3D Widget Inspector View.
  * Remove the experimental VTK-based Object Visualizer.
  * Update 3rdparty/backward-cpp to version 1.6.
  * Update 3rdparty/lz4 to version 1.9.4.
  * Update 3rdparty/StackWalker.
  * Increase CMake requirement to version 3.16.0.
- Add patches:
  * 0001-Fix-doc-tools-detection.patch
  * gammaray-gles.patch
- Add a Qt6 flavor
- Move plugins to a -shared subpackage.
  gammaray-shared and gammaray-qt6-shared can be coinstalled and
  allow debugging Qt5 or Qt6 applications.
* Tue Dec 28 2021 Fabian Vogt <fabian@ritter-vogt.de>
- Drop Fix_icons_installation.patch and package scaled icons
* Wed Oct 20 2021 Antonio Larrosa <alarrosa@suse.com>
- Fix build by fixing the %%files section for renamed/removed files
* Wed Oct 20 2021 Antonio Larrosa <alarrosa@suse.com>
- Update to version 2.11.3
  * Increase CMake requirement to version 3.4.0 (reflecting reality).
  * Update 3rdparty/StackWalker.
  * Update 3rdparty/backward-cpp.
  * Don't fail self-test for lldb version 10.x.
  * Support for CMAKE_SYSTEM_PROCESSOR amd64.
  * Fix crash when editing the margins property of a QtCharts/ChartView.
  * Fix crash when attaching to an ASAN-enabled application.
  * Register stream operators for Qt::CaseSensitivity.
  * Clean some runtime, compile , CMake warnings, etc.
* Thu Aug  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Remove the duplicate category from the desktop file.
* Tue Jun  8 2021 Christophe Giboudeaux <christophe@krop.fr>
- Don't build gammaray with glslang on Tumbleweed.
  The glslang 11.4.0 update broke the build.
* Mon Dec 28 2020 Wang Jun <jgwang@suse.com>
- Update to version 2.11.2
  * Prefer picking QtQuick items in fully visible parent-child chains.
  * Fix deadlock with Qt 5.15 on high DPI screens.
  * Fix QtQuick detection on older macOS versions.
  * Support for Qt 5.15.
- Drop patches, now upstream:
  * 0001-Fix-build-with-Qt-5.15.patch
  * fix-build-with-qt-5.15-again.patch
* Tue Jun  2 2020 Fabian Vogt <fvogt@suse.com>
- Add another patch to fix build against Qt 5.15:
  * fix-build-with-qt-5.15-again.patch
* Thu May  7 2020 Fabian Vogt <fvogt@suse.com>
- Update to 2.11.1:
  * Add OpenGL ES2 fallback for the Qt3D geometry inspector.
  * Fix assert on empty text document selections.
  * Fix side-effects of using the widget layout overlay on a QSplitter.
  * Fix merging of events in the event monitor.
  * Fix event order in the event monitor.
  * Add event propagation detection for QtQuick pointer events.
  * Fix compilation with QT_NO_OPENGL and QT_NO_SSL.
  * Adapt QtQuick software renderer inspector to changes in Qt 5.14.
  * Fix Android support with Qt 5.14.
  * Fix memory leak in event recording when Qt Quick remote view is active.
  * Fix possible crash during probe destruction.
  * Fix crash due to signal spy changes in Qt 5.14.
  * Fix possible crash in the outbound connections view.
- Drop patches, now upstream:
  * 0001-Fix-build-against-Qt-5.14.patch
* Fri Apr  3 2020 Christophe Giboudeaux <christophe@krop.fr>
- Add upstream patch:
  * 0001-Fix-build-with-Qt-5.15.patch
* Sat Dec  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Add 0001-Fix-build-against-Qt-5.14.patch
* Tue Oct 29 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Wrap VTK BuildRequires with bcond, only used for an experimental,
  optional plugin. As only VTK 7.1 (TW and Leap 15.x have 8.2/8.1)
  is supported the plugin was already disabled during configure.
- Remove graphviz-devel BuildRequires, not needed.
* Wed Jul 10 2019 Christophe Giboudeaux <christophe@krop.fr>
- Disable LTO.
* Sat Jul  6 2019 Wolfgang Bauer <wbauer@tmo.at>
- Update to 2.11.0:
  * Drop support for Qt 4 and Qt <= 5.4.
  * Drop support for MSVC 2010 and MSVC 2012, as well as GCC < 4.8.
  * Add support for more QtNetwork properties.
  * Add new network operations monitoring tool.
  * Fix inspection of QJson types.
  * Add thread affinity check to the problem reporter.
  * Add new event monitoring tool.
  * Initial forward compatibility with Qt6 build system.
  * Improved performance of the Qt Quick 2 inspector and the signal
    monitor.
- Drop patches merged upstream:
  * fix-build-with-qt-5.13.patch
  * 0001-Make-sure-the-defined-variables-are-relative-before-.patch
  * Adapt-to-Qt-5.13-changes-for-attached-property-handling.patch
  * Adapt-to-attached-property-changes-in-Qt-5.12.4.patch
- Cleanup specfile: remove conditionals for no longer supported
  distributions
* Mon Jun 17 2019 Wolfgang Bauer <wbauer@tmo.at>
- Add upstream patches to fix build with Qt 5.12.4 and 5.13:
  * Adapt-to-Qt-5.13-changes-for-attached-property-handling.patch
  * Adapt-to-attached-property-changes-in-Qt-5.12.4.patch
* Tue May 14 2019 Christophe Giboudeaux <christophe@krop.fr>
- Add 0001-Make-sure-the-defined-variables-are-relative-before-.patch
  to fix runtime issues.
* Wed Apr 10 2019 Christophe Giboudeaux <christophe@krop.fr>
- Add fix-build-with-qt-5.13.patch
* Tue Apr  2 2019 Christophe Giboudeaux <christophe@krop.fr>
- Remove the vtk-tcl dependency.
* Thu Feb 28 2019 wbauer@tmo.at
- Update to 2.10.0:
  * Increase CMake requirement to version 3.1 on all platforms.
  * Add object navigation to the paint analyzer.
  * Reduce network load by moving more property model features to
    the client side.
  * Port object hierarchy visualizer plugin to Qt 5.
  * Add new system information plugin, which supersedes the
    standard paths plugin.
  * Use application palette rather than style palette in the style
    inspector.
  * Improve gdb injector performance.
  * Reduce performance impact of the widget paint analyzer in
    Windows debug builds.
  * Improve Qt Quick item picking in case of zero-sized parent
    elements.
  * Provide access to QAbstractItemModel role name mapping.
  * Add QtPositioning plugin allowing to monitor and simulate geo
    localization.
  * Add NMEA geo localization playback.
  * Add support for generic functor property accessors.
  * Add property access for mime data and clipboard types.
  * Add infrastructure to override generic property access, such as
    Qt Quick anchor properties.
  * Add custom property access for Qt Quick anchors properties to
    no longer trigger their on-demand creation.
  * Add generic problem reporter infrastructure, and port some
    existing checks to it.
- Drop patches merged upstream:
  * fix-build-qt-5.12.patch
  * fix-build-qt-5.12-again.patch
* Wed Nov 14 2018 Christophe Giboudeaux <christophe@krop.fr>
- Remove unneeded build dependencies.
* Fri Oct  5 2018 fabian@ritter-vogt.de
- Add patches to fix build against Qt 5.12:
  * fix-build-qt-5.12.patch
  * fix-build-qt-5.12-again.patch
* Thu Oct  4 2018 fabian@ritter-vogt.de
- Update to 2.9.1:
  * Fix crash in in-process mode with networking disabled.
  * Fix compilation with Qt 5.12.
  * Update Android toolchain file.
  * Allow to disable QtScript dependency.
  * Fix crash on zero-sized paint operations.
  * Fix plugin deployment on Android.
  * Fix crash in Qt Quick inspector when encountering invalid bounding rects.
  * Fix activating the Qt3D plugin when attaching to a Qt3D application at runtime.
  * Fix out-of-bounds framebuffer read in Qt Quick remote view for some non-integer scaling factors.
- Use %%license
* Fri Feb  9 2018 alarrosa@suse.com
- Update to 2.9.0:
  * Improve Qt Quick Controls 2 tracer coloring.
  * Fix issues with QSG diagnostic render modes in combination with QQuickWidget.
  * Improve input validation in the connect dialog.
  * Fix Qt Quick remote view on targets without GL_BGRA support.
  * Add texture and texture atlas inspection for QSGMaterial using objects.
  * Only read and send the actually visible screen content in the Qt Quick remote view.
  * Support dynamic shaders in the QSGMaterial shader view.
  * Show vertex and fragment uniforms for shader effects in the QSGMaterial tab.
  * Fix crashes during changing/restoring QSG diagnostic render modes.
  * Batch row/column count requests for better remote model performance.
  * Drop support for CMake 2.8, at least 3.0 is required now.
  * Improved performance in the Qt Quick inspector.
  * Add support for QSGRenderNode.
  * Consider compiler version as part of the probe ABI on Windows.
  * Fix multithreading issues in the timer inspector.
  * Add search line to timer inspector.
  * Add screenshot support in Qt Quick inspector.
  * Improve item picking support in Qt Quick inspector.
  * Add texture waste indicator to texture inspection tab.
  * Add color picker for remote views.
  * Add object navigation and source navigation to the timer inspector.
  * Add support for cross-architecture injection on Windows.
  * Add support for editing enum/flag properties not registered with the Qt meta object system.
  * Add network configuration view.
  * Improved indication that a target process is being inspected by GammaRay.
  * Add widget tab focus chain visualization.
  * Fix re-attaching to a target application on Windows.
  * Add QML binding inspector (requires Qt 5.10 or newer).
  * Add support for QtWebEngine to the web inspector tool.
  * Improved argument inspection in the QPainter analyzer.
  * Support paint analysis with the Qt Quick software renderer (requires Qt 5.9.3 or newer).
  * Improved Qt Quick anchor property display.
  * Fix property editing of gadget value types.
  * Fix interaction issues in string type property editor.
  * Add action to slow down Qt Quick animation timers.
  * Add support for visualizing clip areas in the Qt Quick software renderer.
  * Clear Qt Quick target overlay on GammaRay client disconnect.
  * Add automatic down-cast support to GammaRay metatype system.
  * Add QObject creation stack trace view.
  * Add source code navigation to the message browser stack trace view.
  * Add stack trace view for painter operations in the paint analyzer view.
  * Fix rpath support in probe ABI detection on macOS.
  * Fix user manual access on macOS.
  * Add profiling support to the paint analyzer.
  * Use relative RPATHs on Linux, to make installations fully relocatable.
  * Add mouse wheel zoom in the Qt 3D geometry inspector.
  * Improve performance of the Qt Quick scene graph model.
  * Improve editing of boolean properties.
  * Add diagnostic shading modes to the Qt 3D geometry inspector.
  * Support vertex picking in the Qt 3D geometry inspector.
  * Support Qt 3D painted textures in the paint analyzer.
  * Fix Qt 3D buffer decoding for tightly packed attributes.
  * Fix server-side decoration state going out-of-sync in the Qt Quick inspector.
  * Fix crash when validating dynamic meta objects.
  * Fix support of namespaced and semi-qualified enums/flags.
- Update to 2.8.2:
  * Fix high-dpi icon installation.
  * Fix documentation build with spaces in the path.
  * Fix build of the QtIvi inspector with Qt 5.10.
  * Fix detection of libdl.
  * Fix incomplete installation of multi-probe builds on second make install run.
  * Fix build issues in some Windows and cross-compilation setups.
  * Fix widget export action plugin loading on Windows.
- Rebase Fix_icons_installation.patch
* Wed Nov  1 2017 christophe@krop.fr
- Update to 2.8.1:
  * Fix compilation with interestingly packaged qmllint on Ubuntu.
  * Fix error handling in LLDB injector when LLDB scripting support is not available.
  * Fix tree view corruption when searching.
  * Fix linking with backward-cpp in BFD mode using a static libbdf.
  * Fix assert when launching a Windows target using a Qt debug build.
  * Fix crash during attaching on Windows.
  * Fix build with MSVC2010 and Qt4.8.
  * Fix attach dialog not seeing 32bit processes on 64bit Windows systems.
  * Add support for Qt 5.9.2.
- Add Fix_icons_installation.patch.
* Sat Jun 17 2017 fabian@ritter-vogt.de
- Update to 2.8.0:
  * Fix possible deadlock in WinDLL injector.
  * Add code navigation for C++-created objects (Linux-only, requires a debug build).
  * Add legend for the QtQuick inspector overlay.
  * Add QtQuickControls2 layout support in the QtQuick inspector.
  * Add layouting grid overlay to the QtQuick inspector.
  * Add support for non-QtIviProperty properties in QtIvi modules.
  * Improved QtQuick2 remote view performance.
  * Basic support for the QtQuick2 software renderer.
  * Add QtQuick Control 2 tracing support.
  * ... and much more than can fit here. See the changelog for details:
  https://github.com/KDAB/GammaRay/releases/tag/v2.8.0
* Fri Feb 17 2017 alarrosa@suse.com
- Update to 2.7.0:
  * Improved enum and flag editor in the property view.
  * Add style hint view to style inspector.
  * Fix runtime QSG visualization mode switching for newer Qt versions.
  * Initial support for statically compiling GammaRay into a target.
  * Support for QtWayland 5.8.
  * Add object navigation for the translation inspector.
  * Automatically re-scan meta types to captures types registered later.
  * Improved Wayland log and timeline view.
  * Add object navigation for Wayland clients.
  * Show alive object statistics in the meta object browser.
  * Add Qt3D geometry inspector (requires Qt >= 5.7 and Qt3D)
  * Allow to hide inactive tools.
  * Fix handling of partially out-of-view QQuickItems in the QQ2 inspector.
  * Improve error handling in the GDB injector.
  * Fix QML support not being activated when attaching to a QtQuick application at runtime.
  * Fix widget layout overlay for nested QLayouts.
  * Fix crash on client disconnect.
  * Syntax highlighting and code folding for textual content (requires KF5::SyntaxHighlighting)
  * Add 3D widget layout visualization.
  * Allow to hide non-visible elements in the full-depth picking dialog.
  * Add QtIvi inspection tool (requires Qt5IviCore)
  * Fix QSG geometry inspector not showing geometry correctly on first selection.
  * Build both release and debug probes by default when using MSVC.
  * Add more editor defaults for code navigation on Linux.
  * Add QtSCXML support to the state machine debugger (requires Qt >= 5.8).
  * Show QtQuick overlays also in the target application.
  * Avoid leaking GammaRay translated strings into the translation inspector.
  * Fix launching targets on macOS >= 10.9.
- When building for at least Leap 42.2, BuildRequire glslang-devel
  which is an optional package
- When building for Factory, BuildRequire cmake(KF5yntaxHighlighting)
  which is an optional package
* Sun Jan 29 2017 jengelh@inai.de
- Directly call ldconfig as scriptlet
* Thu Oct 27 2016 alarrosa@suse.com
- Update to 2.6.0:
  * Reworked tool view handling, enabling deeper IDE integration of individual tools.
  * Merged model and selection model inspector.
  * Fixed crash when quickly changing selection in model inspector.
  * Add QMetaObject validation, identifying common problems with signal/slot declarations.
  * Support object navigation to and from the model and text document inspectors as well as the signal plotter.
  * Visualize model selections.
  * Allow to inspect model content also for disabled cells.
  * Show model cell flags in model inspector.
  * Fix sorting in object method view.
  * Fix handling of source model changes for proxy and selection models.
  * Add in-app picking for selection models and actions.
  * Extended the user manual with example problems diagnosed with GammaRay.
  * Allow to rescan the meta type database.
  * Add object navigation from the meta type view to the meta object browser.
  * Show registered comparison and stream operators in the meta type browser.
  * Add object navigation support to the action and timer inspectors.
  * Visualize enabled state in the action inspector too.
  * Support editing of nested properties of value types.
  * Fix various enum/flag display issues in the property view.
  * Fix AArch64 detection on ELF platforms.
  * Support ABI detection on systems without ldd.
  * Add Wayland compositor inspector.
  * Add advanced element picking mode for widget and Qt Quick inspectors.
  * Fix crash when encountering an empty translation context.
  * Extend user manual content.
  * Fix a number of memory leaks.
  * Fix crash when selecting a dangling top-level layout in the widget inspector.
  * Fix missing standard icon types in style inspector for some Qt versions.
  * Fix table layout in style inspector.
  * Fix invalid memory access in palette model.
  * Fix selecting entries in the resource browser.
* Sat Oct 22 2016 hrvoje.senjan@gmail.com
- Bump Qt BuildRequires to 5.2.0
* Fri Jul  1 2016 toddrme2178@gmail.com
- Make Group tag consistent with other packages.
* Sat Jul 11 2015 hrvoje.senjan@gmail.com
- Update to 2.3.0:
  * Add QtBluetooth support.
  * Support local sockets next to TCP for connecting to the probe.
  * Change probe plugin loading to be compatible with Android .apk
    restrictions.
  * Don't generate backtraces for GammaRay-caused qWarnings.
  * Also show properties defined in a meta object in the meta
    object browser.
  * Add non-QObject meta object found via QMetaType to the meta
    object browser (finds Q_GADGETs with Qt 5.5).
  * Performance improvements in object tracking, remote model,
    property view, signal spy and several other places.
  * Ongoing refactoring work to enable embedding the
    GammaRay client and launcher components into other
    host applications.
  * Add copy backtrace feature in the message browser.
  * Improved UI-less build option for embedded targets.
  * Fix various crashes, including when interacting with
    QOpenGLContext, QDBusAdapter, QML ListModels or Qt containers
    containing types that cannot be serialized.
  * Make paint analyzing also work with Qt 5.5 despite the necessary
    functionality being removed in Qt.
  * Add support for static properties in the property view.
  * Qt 5.5 compatibility.
  * Initial support for QNX 6.6.
  * Improved QtQuick2 in-app item picking.
  * Fixed/improved tracking of object reparenting in the
    object tree model.
  * Fix widget layout overlay widget leaking into
    object/widget tree.
  * Optional compression support for the client/server communication,
    speeds up debugging over slow USB connections.
  * Fix initial selection in the model browser having no effect.
* Thu Apr  9 2015 hrvoje.senjan@gmail.com
- Update to 2.2.1:
  * Fix spawning a large number of threads in the process list.
  * Add GAMMARAY_BUILD_UI build option to only build the non-UI
    parts, useful for embedded targets.
  * Add workaround for QSortFilterProxyModel regression introduced
    in qtbase commit bec1854cc0.
  * Follow kdstatemachineeditor KDSME API changes.
  * Use the preload injector by default on Mac for Qt >= 5.4.
  * Fix probe ABI detection on Mac bundles.
  * Fix asserts caused by icon loading in
    QCoreApplication-only targets.
  * Fix crash when target deletes a signal sender in a slot.
  - Changes since 2.2.0:
  * New translation inspector plug-in.
  * New signal monitor and object lifetime plotter plug-in.
  * Support displaying of QQmlListProperty contents.
  * Expose signal/slot spy callback API to plug-ins.
  * Improved state machine visualization using KDSME.
  * Support for QQmlTimer in the timertop plug-in.
  * Support exporting of QResource data.
  * Improved QSGMaterial viewer.
  * Various performance improvements for the QtQuick2
    remote preview.
  * Improved Qt 5.4 compatibility.
  * Fix handling of large images in the resource browser.
  * Support for manually emitting signals, and improved
    method display.
  - Changes since 2.1.2:
  * Fix crash when selecting the scene graph root node.
  * Fix two asserts in Qt 5.4 when dealing with connections
    to slot objects.
  * Fix build with Vivante OpenGL ES2 stack.
  * Build fixes for Android.
  * Fix build issues with Qt5.4 and Clang.
  * Fix minor compiler warnings and Coverity Scan issues.
  - Changes since 2.1.1:
  * Fix invoking non-slot methods with arguments.
  * Fix QtQuick2 preview not showing any content with
    Qt 5.2 or older.
  * Fix crash when encountering tooltips in Qt5 targets.
  * Fix deadlock in object list model.
  * Fix QGraphicsView scene selection in in-process mode.
  * Fix debug message handler for Qt5.
  * A missing relocatable startup hook is
    no longer fatal with Qt 5.4.
  * Fix Qt 5.4 compatibility of the QtQuick2 preview.
  - Changes since 2.1.0:
  * Aggregated property view combining static, dynamic and
    non-QObject property views.
  * Qt5Qml/Qt5Quick support
    (see http://github.com/KDAB/GammaRay/wiki/QtQuick2-Support-Status)
  * Probe ABI auto-detection on Linux, Mac and Windows.
  * Support to navigate to objects that are property values.
  * Plug-ins can now add specialized tabs to the property view.
  * Support adding and deleting dynamic QObject properties.
  * Support for "hidden" plug-ins, i.e. plug-ins that only
    provide type support but no own tool view.
  * Support KF5 in the KJob tracker plug-in.
  * Support for Qt 5.4 object creation/destruction callbacks.
  * Improved connection view, and support for viewing
    connections in Qt5 applications.
  - Changes since 2.0.2:
  * Restore compatibility with Qt4.7
  * Avoid leaking shared-memory in case of crashes of gammaray-client
  * Fix various crashes
  * Fix various crashes with heavily multithreaded debuggees
  * Fix unnecessary value limits in property editor for
    QPointF, QSizeF, etc
  * Improve property editor value loading performance
  - Changes since 2.0.1:
  * LLDB injector (enables Mac OSX 10.9 support)
  * Fix various cases where client and server states get out of sync
  - Changes since 2.0.0:
  * Out-of-process UI
  * Remote Debugging
  * Multi-probe support
  * Probe usable on targets without QtWidget available
  * Fix preload check on MIPS/MIPSel (issue #63)
  * Support for displaying arguments of monitored signals
- Drop libQtWebKit-devel and libkde4-devel BuildRequires
- Added pkgconfig(Qt5Concurrent), pkgconfig(Qt5Core),
  pkgconfig(Qt5Designer), pkgconfig(Qt5Gui), pkgconfig(Qt5Network),
  pkgconfig(Qt5PrintSupport), pkgconfig(Qt5Qml) >= 5.1.0,
  pkgconfig(Qt5Quick), pkgconfig(Qt5Script),
  pgconfig(Qt5ScriptTools), pkgconfig(Qt5Svg), pkgconfig(Qt5Test),
  pkgconfig(Qt5WebKitWidgets), pkgconfig(Qt5Widgets),
  libQt5Core-private-headers-devel, libQt5Gui-private-headers-devel,
  libQt5Network-private-headers-devel and
  libqt5-qtdeclarative-private-headers-devel BuildRequires
- Enable devel subpackage
* Sat Dec  7 2013 cgiboudeaux@gmx.com
- Update to 1.3.2:
  * Support more Qt5-specific data types
  * Fix crash on some QtQuick2 applicaitons
  * Support VTK6
  * Fix crash in selection model inspector
  * Fix probe re-injections
* Mon Aug  5 2013 hrvoje.senjan@gmail.com
- enable CMAKE_SKIP_INSTALL_RPATH option so RPATH is ommited from
  install tree
* Sun Jul 21 2013 hrvoje.senjan@gmail.com
- Update to 1.3.1:
- Changes since 1.3.0:
  * Fix state machine viewer on Windows
  * Fix crash in model cell viewer
  * Fix crash in meta object browser caused by deleted dynamic
  meta objects
  * Improve performance of the mime type browser
  * Improvements in the state machine viewer image export
  * Compile fixes for some Qt5 configurations
- Changes since 1.2.0:
  * New KJob tracker plugin (requires KDE4)
  * Qt5 support
  * New Meta Object Browser tool
  * New QStandardPaths and QMimeTypeDatabase browsers (Qt5 only)
- Changes since 1.1.1:
  * Published API for writing your own plugin
  * New QStyle inspector
  * New QAction inspector with shortcut conflict finder
  * New QPalette editor
  * QWidget paint operation introspection using QPaintBuffer
  (requires private headers)
- Dropped gammaray-gcc47.patch, not needed
- Added libkde4-devel, python-devel, graphviz-devel and libxml2-devel
  BuildRequires
- Added qvtk.diff, so variable is used, instead of hardcoded QVTK
- Adjust license format
* Tue Nov 20 2012 nico.kruber@gmail.com
- Fix the SLES build (%%make_install is not expanded on SLES)
* Tue May 15 2012 idonmez@suse.com
- Fix compilation with gcc 4.7
* Mon Mar 19 2012 toddrme2178@gmail.com
- Update to version 1.1.0
- Added vtk dependencies for viewing source structure
- Cleaned up spec file formatting
* Thu Nov  3 2011 idonmez@suse.com
- Fix build on openSUSE 11.4 and lower
* Sun Oct 30 2011 wstephenson@suse.com
- Initial version 1.0.50
